import {
  Form,
  Input,
  Select,
} from "antd";
import { Create, useForm } from "@refinedev/antd";
import { Col, Row, Card } from "antd";
import { ClientFormData, PlanType } from "../../types/client";

export const ClientCreate = () => {
  const { formProps, saveButtonProps } = useForm<ClientFormData>({
    redirect: "list",
    onMutationSuccess: (data) => {
      console.log("Client created successfully:", data);
    },
    onMutationError: (error) => {
      console.error("Error creating client:", error);
    },
  });

  return (
    <Create saveButtonProps={saveButtonProps}>
      <Form {...formProps} layout="vertical">
        <Card title="Client Information" style={{ marginBottom: 16 }}>
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                label="Name"
                name="name"
                rules={[
                  {
                    required: true,
                    message: "Please enter client name",
                  },
                ]}
              >
                <Input placeholder="Client name" />
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                label="Organization"
                name="organization"
                rules={[
                  {
                    required: true,
                    message: "Please enter organization name",
                  },
                ]}
              >
                <Input placeholder="Organization name" />
              </Form.Item>
            </Col>
          </Row>
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                label="Contact Email"
                name="contactEmail"
                rules={[
                  {
                    required: true,
                    message: "Please enter contact email",
                  },
                  {
                    type: "email",
                    message: "Please enter a valid email",
                  },
                ]}
              >
                <Input placeholder="contact@example.com" />
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                label="Contact Phone"
                name="contactPhone"
                rules={[
                  {
                    message: "Please enter a valid phone number",
                    pattern: /^\+?[0-9()-\s]+$/,
                  },
                ]}
              >
                <Input placeholder="Phone number (optional)" />
              </Form.Item>
            </Col>
          </Row>
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                label="Plan"
                name="plan"
                initialValue="basic"
                rules={[
                  {
                    required: true,
                    message: "Please select a plan",
                  },
                ]}
              >
                <Select placeholder="Select a plan">
                  <Select.Option value="basic">Basic</Select.Option>
                  <Select.Option value="pro">Pro</Select.Option>
                  <Select.Option value="enterprise">Enterprise</Select.Option>
                </Select>
              </Form.Item>
            </Col>
          </Row>
        </Card>
      </Form>
    </Create>
  );
};