import React from 'react';
import { Create, useForm } from "@refinedev/antd";
import { Form, Input, Select, Button, Card } from 'antd';
import { ComponentFormData, ComponentType } from '../../types/component';

export const ComponentCreate = () => {
  const { formProps, saveButtonProps, formLoading } = useForm<ComponentFormData>();
  
  return (
    <Create saveButtonProps={saveButtonProps}>
      <Form {...formProps} layout="vertical">
        <Card title="Component Information" style={{ marginBottom: 20 }}>
          <Form.Item
            label="Name"
            name="name"
            rules={[{ required: true, message: 'Please enter a component name' }]}
          >
            <Input placeholder="Enter component name" />
          </Form.Item>
          
          <Form.Item
            label="Description"
            name="description"
            rules={[{ required: true, message: 'Please enter a description' }]}
          >
            <Input.TextArea 
              rows={4} 
              placeholder="Describe the purpose of this component" 
            />
          </Form.Item>
          
          <Form.Item
            label="Type"
            name="type"
            rules={[{ required: true, message: 'Please select a component type' }]}
          >
            <Select placeholder="Select component type">
              <Select.Option value="frontend">Frontend</Select.Option>
              <Select.Option value="backend">Backend</Select.Option>
              <Select.Option value="api">API</Select.Option>
              <Select.Option value="database">Database</Select.Option>
              <Select.Option value="microservice">Microservice</Select.Option>
            </Select>
          </Form.Item>
          
          <Form.Item
            label="Language"
            name="language"
            rules={[{ required: true, message: 'Please enter the programming language' }]}
          >
            <Input placeholder="E.g., JavaScript, Python, Go" />
          </Form.Item>
          
          <Form.Item
            label="Version"
            name="version"
            rules={[{ required: true, message: 'Please enter the version' }]}
          >
            <Input placeholder="E.g., 1.0.0" />
          </Form.Item>
        </Card>
        
        <Card title="Configuration" style={{ marginBottom: 20 }}>
          <Form.Item
            label="Config File Path"
            name="configFile"
            rules={[{ required: true, message: 'Please enter a config file path' }]}
          >
            <Input placeholder="Path to configuration file" />
          </Form.Item>
          
          <Form.Item
            label="Environment Variables"
            name="envVariables"
          >
            <Input.TextArea 
              rows={4} 
              placeholder="KEY=value (one per line)"
            />
          </Form.Item>
        </Card>
        
        <Card title="Source Code" style={{ marginBottom: 20 }}>
          <Form.Item
            label="Repository URL"
            name="repository"
          >
            <Input placeholder="Git repository URL" />
          </Form.Item>
          
          <Form.Item
            label="Branch"
            name="branch"
          >
            <Input placeholder="E.g., main, master" />
          </Form.Item>
          
          <Form.Item
            label="Build Command"
            name="buildCommand"
          >
            <Input placeholder="E.g., npm run build" />
          </Form.Item>
        </Card>
        
        <Card title="Resources">
          <Form.Item
            label="Resource Requirements"
            name="resources"
          >
            <Input.TextArea 
              rows={4} 
              placeholder="Resource requirements in YAML format"
            />
          </Form.Item>
          
          <Form.Item
            label="Scale Settings"
            name="scaleSettings"
          >
            <Input.TextArea 
              rows={4} 
              placeholder="Scaling configuration in YAML format"
            />
          </Form.Item>
        </Card>
      </Form>
    </Create>
  );
};
