import {
  DeleteButton,
  EditButton,
  List,
  ShowButton,
  useTable,
  TagField,
} from "@refinedev/antd";
import type { BaseRecord } from "@refinedev/core";
import { Space, Table, Tag, Button, Typography } from "antd";
import { PlusOutlined, AppstoreOutlined } from "@ant-design/icons";

const { Title } = Typography;

export const ComponentList = () => {
  const { tableProps } = useTable({
    syncWithLocation: true,
  });

  return (
    <>
      <div style={{ display: "flex", justifyContent: "space-between", alignItems: "center", marginBottom: 16 }}>
        <Title level={4}>Components</Title>
        <Button type="primary" icon={<PlusOutlined />} href="/components/create">
          Create New Component
        </Button>
      </div>

      <List>
        <Table {...tableProps} rowKey="id">
          <Table.Column dataIndex="id" title="ID" />
          <Table.Column dataIndex="name" title="Component Name" />
          <Table.Column dataIndex="description" title="Description" />
          <Table.Column 
            dataIndex="type" 
            title="Component Type" 
            render={(value) => {
              const colorMap: Record<string, string> = {
                frontend: 'blue',
                backend: 'green',
                api: 'purple',
                database: 'orange',
                microservice: 'cyan',
              };
              
              return (
                <Tag color={colorMap[value] || 'default'}>
                  {value?.toUpperCase()}
                </Tag>
              );
            }}
          />
          <Table.Column
            dataIndex="language"
            title="Language"
            render={(value) => (
              <TagField value={value} />
            )}
          />
          <Table.Column
            title="Actions"
            dataIndex="actions"
            render={(_, record: BaseRecord) => (
              <Space>
                <ShowButton hideText size="small" recordItemId={record.id} />
                <EditButton hideText size="small" recordItemId={record.id} />
                <DeleteButton hideText size="small" recordItemId={record.id} />
              </Space>
            )}
          />
        </Table>
      </List>
    </>
  );
};
