import {
  DeleteButton,
  EditButton,
  List,
  ShowButton,
  useTable,
  TagField,
} from "@refinedev/antd";
import type { BaseRecord } from "@refinedev/core";
import { Space, Table, Tag } from "antd";

export const DeploymentList = () => {
  const { tableProps } = useTable({
    syncWithLocation: true,
  });

  return (
    <List>
      <Table {...tableProps} rowKey="id">
        <Table.Column dataIndex="id" title={"ID"} />
        <Table.Column dataIndex="name" title={"Deployment Name"} />
        <Table.Column dataIndex="clientName" title={"Client"} />
        <Table.Column
          title={"App"}
          render={(_, record: BaseRecord) => (
            <Space>
              <Tag color="blue">
                <a href={`/apps/show/${record.appId}`}>
                  App {record.appId}
                </a>
              </Tag>
            </Space>
          )}
        />
        <Table.Column
          dataIndex="status"
          title={"Status"}
          render={(value) => {
            let color = 'green';
            if (value === 'pending') {
              color = 'orange';
            } else if (value === 'failed') {
              color = 'red';
            }
            return <Tag color={color}>{value.toUpperCase()}</Tag>;
          }}
        />
        <Table.Column dataIndex="version" title={"Version"} />
        <Table.Column dataIndex="deploymentDate" title={"Deployed On"} />
        <Table.Column
          title={"Actions"}
          dataIndex="actions"
          render={(_, record: BaseRecord) => (
            <Space>
              <ShowButton hideText size="small" recordItemId={record.id} />
              <EditButton hideText size="small" recordItemId={record.id} />
              <DeleteButton hideText size="small" recordItemId={record.id} />
            </Space>
          )}
        />
      </Table>
    </List>
  );
};