/**
 * App data model that matches the Golang backend implementation
 * (Apps were previously called Templates)
 */

import { Deployment } from './deployment';

export interface App {
    id: number;
    name: string;
    description: string;
    version: string;
    // Configuration
    config: AppConfig;
    // Metadata
    createdAt: string;
    updatedAt: string;
    createdBy: number;
    // Relationships
    deployments?: Deployment[];
}

export interface AppConfig {
    components: ComponentConfig[];
    networkPolicies: NetworkPolicy[];
    envVariables?: Record<string, string>;
    secrets?: SecretConfig[];
}

export interface ComponentConfig {
    id: number;
    name: string;
    exposedPorts?: number[];
    publicAccess: boolean;
    resources: ResourceConfig;
    autoscaling?: AutoscalingConfig;
    envOverrides?: Record<string, string>;
    serviceMesh: boolean;
}

export interface ResourceConfig {
    cpu: string;
    memory: string;
    storage: string;
}

export interface AutoscalingConfig {
    enabled: boolean;
    minReplicas: number;
    maxReplicas: number;
    cpuThreshold: number;
    metric: string;
}

export interface NetworkPolicy {
    name: string;
    fromComponents: string[];  // Updated to match backend
    toComponents: string[];    // Updated to match backend
    ports?: number[];
    allowEgress: boolean;
}

export interface SecretConfig {
    name: string;
    description: string;
    required: boolean;
}

export interface AppFormData {
    name: string;
    description: string;
    version: string;
    config: {
        components: ComponentConfig[];
        networkPolicies: NetworkPolicy[];
        envVariables?: Record<string, string>;
        secrets?: SecretConfig[];
    };
}
