
import { Deployment } from './deployment';
/**
 * Client data model that matches the backend API structure
 */
export interface Client {
  id: number;
  name: string;
  contactEmail: string;
  contactPhone?: string;
  organization: string;
  plan: PlanType;
  createdAt: string;
  updatedAt: string;
  deletedAt?: string;

  // Relationships
  deployments?: Deployment[];
}

export type PlanType = 'basic' | 'pro' | 'enterprise';

export interface Address {
  street: string;
  city: string;
  state: string;
  postalCode: string;
  country: string;
}

export interface Subscription {
  plan: SubscriptionTier;
  startDate: string;
  renewalDate: string;
  paymentStatus: PaymentStatus;
  features: string[];
  limits: ResourceLimits;
}

export type PaymentStatus =
  | 'active'
  | 'pending'
  | 'overdue'
  | 'cancelled';

export interface ResourceLimits {
  maxDeployments: number;
  maxApps: number;
  maxCpuPerDeployment: string;
  maxMemoryPerDeployment: string;
  maxStorageTotal: string;
  supportSLA: string;
}

export interface ClientFormData {
  name: string;
  contactEmail: string;
  contactPhone?: string;
  organization: string;
  plan: PlanType;
}

export type SubscriptionTier =
  | 'basic'
  | 'pro'
  | 'enterprise';