/**
 * Deployment data model that matches the UI components in the deployments section
 */
export interface Deployment {
  id: number;
  name: string;
  clientId: number;
  clientName?: string;
  appId: number;  // Updated from blueprintId (templates are now apps)
  status: DeploymentStatus;
  version: string;
  environment: Environment;
  containerCount: number;

  // Status & monitoring info
  healthStatus?: HealthStatus;
  cpuUsage?: number;
  memoryUsage?: number;
  storageUsage?: number;

  // Dates
  deploymentDate: string;
  updatedAt: string;
  createdAt: string;

  // Relationships
  deployedComponents?: DeployedComponent[];
}

export type DeploymentStatus =
  | 'pending'
  | 'deploying'
  | 'active'
  | 'failed'
  | 'updating'
  | 'deleting';

export type Environment =
  | 'development'
  | 'staging'
  | 'production';

export type HealthStatus =
  | 'healthy'
  | 'degraded'
  | 'unhealthy';

export interface DeployedComponent {
  componentId: number;
  status: ComponentDeploymentStatus;
  version: string;
  url?: string;
  podCount?: number;
  healthStatus?: HealthStatus;
  configSnapshot: string;
}

export type ComponentDeploymentStatus =
  | 'pending'
  | 'running'
  | 'failed'
  | 'scaling'
  | 'updating';

export interface DeploymentFormData {
  name: string;
  clientId: number;
  appId: number;  // Updated from blueprintId (templates are now apps)
  version: string;
  containerCount: number;
  environment: Environment;
}